{
  withSystem,
  inputs,
  ...
}: {
  # perSystem = { ... }: { config.packages.hello = ...; };

  flake.nixosConfigurations.inst = withSystem "x86_64-linux" (
    ctx @ {
      config,
      inputs',
      ...
    }:
      inputs.nixpkgs.lib.nixosSystem {
        # Expose `packages`, `inputs` and `inputs'` as module arguments.
        # Use specialArgs permits use in `imports`.
        # Note: if you publish modules for reuse, do not rely on specialArgs, but
        # on the flake scope instead. See also https://flake.parts/define-module-in-separate-file.html
        specialArgs = {
          packages = config.packages;
          inherit inputs inputs';
        };
        modules = [
          "${inputs.nixpkgs}/nixos/modules/installer/cd-dvd/installation-cd-graphical-calamares-plasma5.nix"
          "${inputs.nixpkgs}/nixos/modules/installer/cd-dvd/channel.nix"
          inputs.nixos-hardware.nixosModules.microsoft-surface-common
          (
            # NixOS-WSL specific options are documented on the NixOS-WSL repository:
            # https://github.com/nix-community/NixOS-WSL
            {
              config,
              lib,
              pkgs,
              ...
            }: {
              imports = [
              ];
              nixpkgs.hostPlatform = lib.mkDefault "x86_64-linux";

              nix.settings.experimental-features = [
                "nix-command"
                "flakes"
              ];

              networking.hostId = "9affdaa4";

              environment.systemPackages = with pkgs; [
              ];

              time.timeZone = "America/Kentucky/Louisville";

              # This value determines the NixOS release from which the default
              # settings for stateful data, like file locations and database versions
              # on your system were taken. It's perfectly fine and recommended to leave
              # this value at the release version of the first install of this system.
              # Before changing this value read the documentation for this option
              # (e.g. man configuration.nix or on https://nixos.org/nixos/options.html).
              system.stateVersion = "24.11"; # Did you read the comment?
            }
          )
        ];
      }
  );
}
